@@ -4,37 +4,35 @@ test_that(
   desc = "checking labels and data from plot",
   code = {
     skip_on_cran()
-    skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "4.0")
 
     # creating the plot
     set.seed(123)
-    p <-
-      ggbetweenstats(
-        data = ggplot2::msleep,
-        x = vore,
-        y = brainwt,
-        title = "mammalian sleep",
-        caption = "From ggplot2 package",
-        xlab = "vore",
-        ylab = "brain weight",
-        ggsignif.args = list(textsize = 6, tip_length = 0.01),
-        outlier.tagging = TRUE,
-        outlier.label = name,
-        outlier.label.args = list(color = "darkgreen"),
-        conf.level = 0.99,
-        k = 5
-      )
+    p <- ggbetweenstats(
+      data = ggplot2::msleep,
+      x = vore,
+      y = brainwt,
+      title = "mammalian sleep",
+      caption = "From ggplot2 package",
+      xlab = "vore",
+      ylab = "brain weight",
+      ggsignif.args = list(textsize = 6, tip_length = 0.01),
+      outlier.tagging = TRUE,
+      outlier.label = name,
+      outlier.label.args = list(color = "darkgreen"),
+      conf.level = 0.99,
+      k = 5
+    )
 
     # subtitle
     set.seed(123)
-    p_subtitle <-
-      statsExpressions::oneway_anova(
-        data = ggplot2::msleep,
-        x = vore,
-        y = brainwt,
-        k = 5,
-        conf.level = 0.99
-      )$expression[[1]]
+    p_subtitle <- statsExpressions::oneway_anova(
+      data = ggplot2::msleep,
+      x = vore,
+      y = brainwt,
+      k = 5,
+      conf.level = 0.99
+    )$expression[[1]]
 
     # plot build
     pb <- ggplot2::ggplot_build(p)
@@ -65,25 +63,24 @@ test_that(
   desc = "checking mean labels are working",
   code = {
     skip_on_cran()
-    skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "4.0")
 
     # creating the plot
     set.seed(123)
-    p <-
-      ggbetweenstats(
-        data = tibble::as_tibble(mtcars, rownames = "name") %>%
-          dplyr::rename(n = wt),
-        x = "cyl",
-        y = "n",
-        type = "np",
-        k = 2L,
-        pairwise.comparisons = FALSE,
-        conf.level = 0.90,
-        outlier.tagging = TRUE,
-        outlier.label = "name",
-        outlier.coef = 2.5,
-        results.subtitle = FALSE
-      ) +
+    p <- ggbetweenstats(
+      data = tibble::as_tibble(mtcars, rownames = "name") %>%
+        dplyr::rename(n = wt),
+      x = cyl,
+      y = n,
+      type = "np",
+      k = 2L,
+      pairwise.comparisons = FALSE,
+      conf.level = 0.90,
+      outlier.tagging = TRUE,
+      outlier.label = "name",
+      outlier.coef = 2.5,
+      results.subtitle = FALSE
+    ) +
       ggplot2::coord_cartesian(ylim = c(1, 6)) +
       ggplot2::scale_y_continuous(limits = c(1, 6), breaks = seq(1, 6, 1))
 
@@ -113,13 +110,12 @@ test_that(
     )
 
     # plot
-    p1 <-
-      suppressWarnings(ggbetweenstats(
-        data = a,
-        x = "group",
-        y = "centrality.a",
-        results.subtitle = FALSE
-      ))
+    p1 <- suppressWarnings(ggbetweenstats(
+      data = a,
+      x = group,
+      y = centrality.a,
+      results.subtitle = FALSE
+    ))
 
     # build
     pb1 <- ggplot2::ggplot_build(p1)
@@ -140,41 +136,39 @@ test_that(
   desc = "checking if plot.type argument works",
   code = {
     skip_on_cran()
-    skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "4.0")
 
     # boxplot
     set.seed(123)
-    p1 <-
-      ggbetweenstats(
-        data = ToothGrowth,
-        x = supp,
-        y = len,
-        type = "bayes",
-        plot.type = "box",
-        results.subtitle = FALSE,
-        outlier.tagging = TRUE,
-        outlier.coef = 0.75,
-        outlier.color = "blue",
-        centrality.point.args = list(size = 5, color = "darkgreen"),
-        centrality.label.args = list(color = "blue", nudge_x = 0.4, segment.linetype = 4)
-      )
+    p1 <- ggbetweenstats(
+      data = ToothGrowth,
+      x = supp,
+      y = len,
+      type = "bayes",
+      plot.type = "box",
+      results.subtitle = FALSE,
+      outlier.tagging = TRUE,
+      outlier.coef = 0.75,
+      outlier.color = "blue",
+      centrality.point.args = list(size = 5, color = "darkgreen"),
+      centrality.label.args = list(color = "blue", nudge_x = 0.4, segment.linetype = 4)
+    )
 
     # violin
     set.seed(123)
-    p2 <-
-      ggbetweenstats(
-        data = ToothGrowth,
-        x = supp,
-        y = len,
-        type = "r",
-        results.subtitle = FALSE,
-        plot.type = "violin",
-        outlier.tagging = TRUE,
-        outlier.coef = 0.75,
-        bf.message = FALSE,
-        package = "wesanderson",
-        palette = "Royal1"
-      ) +
+    p2 <- ggbetweenstats(
+      data = ToothGrowth,
+      x = supp,
+      y = len,
+      type = "r",
+      results.subtitle = FALSE,
+      plot.type = "violin",
+      outlier.tagging = TRUE,
+      outlier.coef = 0.75,
+      bf.message = FALSE,
+      package = "wesanderson",
+      palette = "Royal1"
+    ) +
       ggplot2::scale_y_continuous(breaks = seq(0, 30, 5))
 
     # build the plots
@@ -198,28 +192,26 @@ test_that(
   desc = "subtitle output works",
   code = {
     skip_on_cran()
-    skip_if(getRversion() < "3.6")
+    skip_if(getRversion() < "4.0")
 
     df <- mtcars
     df$wt[3] <- NA
 
     # plot
     set.seed(123)
-    subtitle_exp <-
-      ggbetweenstats(
-        data = df,
-        x = am,
-        y = wt,
-        output = "subtitle"
-      )
+    subtitle_exp <- ggbetweenstats(
+      data = df,
+      x = am,
+      y = wt,
+      output = "subtitle"
+    )
 
     set.seed(123)
-    sub <-
-      statsExpressions::two_sample_test(
-        data = df,
-        x = am,
-        y = wt
-      )$expression[[1]]
+    sub <- statsExpressions::two_sample_test(
+      data = df,
+      x = am,
+      y = wt
+    )$expression[[1]]
 
     # test
     expect_identical(subtitle_exp, sub)
