@@ -1,5 +1,3 @@
-
-
 # pearson's r with NAs ---------------------------------------------
 
 test_that(
@@ -114,27 +112,25 @@ test_that(
 
     # creating the plot
     set.seed(123)
-    p <-
-      ggscatterstats(
-        data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
-        x = sleep_total,
-        y = sleep_cycle,
-        type = "r",
-        conf.level = 0.90,
-        point.args = list(color = "red", size = 5, stroke = 0),
-        marginal = FALSE
-      )
+    p <- ggscatterstats(
+      data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
+      x = sleep_total,
+      y = sleep_cycle,
+      type = "r",
+      conf.level = 0.90,
+      point.args = list(color = "red", size = 5, stroke = 0),
+      marginal = FALSE
+    )
 
     # subtitle
     set.seed(123)
-    p_subtitle <-
-      statsExpressions::corr_test(
-        data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
-        x = sleep_total,
-        y = sleep_cycle,
-        type = "r",
-        conf.level = 0.90
-      )$expression[[1]]
+    p_subtitle <- statsExpressions::corr_test(
+      data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
+      x = sleep_total,
+      y = sleep_cycle,
+      type = "r",
+      conf.level = 0.90
+    )$expression[[1]]
 
     pb <- ggplot2::ggplot_build(p)
 
@@ -153,54 +149,39 @@ test_that(
   desc = "bayes factor plus class of object",
   code = {
     skip_on_cran()
-    skip_if_not_installed("ggExtra")
+    skip_if_not_installed("ggside")
 
     # creating the plot
     set.seed(123)
-    p <-
-      ggscatterstats(
-        data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
-        x = sleep_total,
-        y = sleep_cycle,
-        xlab = "total sleep",
-        ylab = "sleep cycle",
-        title = "mammalian sleep dataset",
-        caption = "source: ggplot2 package",
-        type = "bayes",
-        ggplot.component = ggplot2::scale_y_continuous(breaks = seq(0, 6000, 1000))
-      )
+    p <- ggscatterstats(
+      data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
+      x = sleep_total,
+      y = sleep_cycle,
+      xlab = "total sleep",
+      ylab = "sleep cycle",
+      title = "mammalian sleep dataset",
+      caption = "source: ggplot2 package",
+      type = "bayes",
+      ggplot.component = ggplot2::scale_y_continuous(breaks = seq(0, 6000, 1000))
+    )
+
+    pb <- ggplot2::ggplot_build(p)
 
     # subtitle
     set.seed(123)
-    p_subtitle <-
-      statsExpressions::corr_test(
-        data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
-        x = sleep_total,
-        y = sleep_cycle,
-        type = "bayes"
-      )$expression[[1]]
+    p_subtitle <- statsExpressions::corr_test(
+      data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
+      x = sleep_total,
+      y = sleep_cycle,
+      type = "bayes"
+    )$expression[[1]]
 
-    expect_identical(class(p)[[1]], "ggExtraPlot")
-    expect_identical(
-      enframe(p$grobs[[23]]$children)$value[[1]][[1]],
-      "mammalian sleep dataset"
-    )
-    expect_identical(
-      enframe(p$grobs[[17]]$children)$value[[1]][[1]],
-      "source: ggplot2 package"
-    )
-    expect_identical(
-      enframe(p$grobs[[12]]$children)$value[[1]][[1]],
-      "total sleep"
-    )
-    expect_identical(
-      enframe(p$grobs[[13]]$children)$value[[1]][[1]],
-      "sleep cycle"
-    )
-    expect_identical(
-      enframe(p$grobs[[22]]$children)$value[[1]][[1]],
-      p_subtitle
-    )
+    # check just the names and dims and not the actual values
+    set.seed(123)
+    expect_snapshot(purrr::map(pb$data, names))
+    expect_snapshot(purrr::map(pb$data, dim))
+
+    expect_identical(p$labels$subtitle$expr, p_subtitle)
   }
 )
 
@@ -213,19 +194,19 @@ test_that(
 
     # creating the plot
     set.seed(123)
-    p <-
-      ggscatterstats(
-        data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
-        x = sleep_total,
-        y = sleep_cycle,
-        label.expression = "sleep_total > 17",
-        label.var = "order",
-        point.label.args = list(size = 4, color = "blue", alpha = 0.5),
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ) +
-      ggplot2::coord_cartesian(ylim = c(0, 7000)) +
-      ggplot2::scale_y_continuous(breaks = seq(0, 7000, 1000))
+    p <- ggscatterstats(
+      data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
+      x = sleep_total,
+      y = sleep_cycle,
+      label.expression = sleep_total > 17,
+      label.var = order,
+      point.label.args = list(size = 4, color = "blue", alpha = 0.5),
+      ggplot.component = list(
+        ggplot2::coord_cartesian(ylim = c(0, 7000)),
+        ggplot2::scale_y_continuous(breaks = seq(0, 7000, 1000))
+      ),
+      results.subtitle = FALSE
+    )
 
     # build the plot
     pb <- ggplot2::ggplot_build(p)
@@ -234,89 +215,10 @@ test_that(
     set.seed(123)
     expect_snapshot(list(pb$data[[1]], head(pb$data[[2]]), pb$data[[3]]))
     expect_snapshot(pb$plot$labels)
-
-    # both quoted
     expect_s3_class(p, "gg")
   }
 )
 
-# labeling input variations ---------------------------------------------
-
-test_that(
-  desc = "checking ggscatterstats with different kinds of inputs to labeling",
-  code = {
-    skip_on_cran()
-
-    # both quoted
-    expect_true(inherits(
-      ggscatterstats(
-        data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
-        x = sleep_total,
-        y = sleep_cycle,
-        label.expression = "sleep_total > 17",
-        label.var = "order",
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
-
-    # both unquoted
-    expect_true(inherits(
-      ggscatterstats(
-        data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
-        x = sleep_total,
-        y = sleep_cycle,
-        label.expression = sleep_total > 17,
-        label.var = order,
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
-
-    # label.expression not specified
-    expect_true(inherits(
-      ggscatterstats(
-        data = dplyr::sample_frac(dplyr::filter(ggplot2::msleep, conservation == "lc"), 0.1),
-        x = sleep_total,
-        y = sleep_cycle,
-        label.expression = NULL,
-        label.var = order,
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
-  }
-)
-
-# with marginals ----------------------------------------------------------
-
-test_that(
-  desc = "with marginals",
-  code = {
-    skip_on_cran()
-    skip_if_not_installed("ggExtra")
-
-    # creating the plot
-    set.seed(123)
-    p <-
-      ggscatterstats(
-        data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
-        x = sleep_total,
-        y = sleep_cycle,
-        margins = "y",
-        results.subtitle = FALSE
-      )
-
-    expect_identical(
-      class(p),
-      c("ggExtraPlot", "gtable", "gTree", "grob", "gDesc")
-    )
-  }
-)
-
 # subtitle output ----------------------------------------------------------
 
 test_that(
@@ -350,3 +252,69 @@ test_that(
     expect_identical(p_sub, fun_sub)
   }
 )
+
+test_that("plots are rendered correctly - ggscatterstats", {
+  skip_on_cran()
+  skip_if_not_installed("vdiffr")
+  skip_if(getRversion() < "4.1")
+
+  # vdiffr tests --------------------------------
+
+  set.seed(123)
+  vdiffr::expect_doppelganger(
+    title = "label symbol args - vdiffr",
+    fig = ggscatterstats(
+      data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
+      x = sleep_total,
+      y = sleep_cycle,
+      label.expression = sleep_total > 17,
+      label.var = order,
+      results.subtitle = FALSE
+    )
+  )
+
+  set.seed(123)
+  vdiffr::expect_doppelganger(
+    title = "label var NULL - vdiffr",
+    fig = ggscatterstats(
+      data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
+      x = sleep_total,
+      y = sleep_cycle,
+      label.expression = sleep_total > 17,
+      label.var = NULL,
+      results.subtitle = FALSE
+    )
+  )
+
+  set.seed(123)
+  vdiffr::expect_doppelganger(
+    title = "label expr NULL - vdiffr",
+    fig = ggscatterstats(
+      data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
+      x = sleep_total,
+      y = sleep_cycle,
+      label.expression = NULL,
+      label.var = order,
+      results.subtitle = FALSE
+    )
+  )
+
+  set.seed(123)
+  vdiffr::expect_doppelganger(
+    title = "changing scales and aesthetics - vdiffr",
+    fig = ggscatterstats(mtcars, wt, mpg,
+      xsidehistogram.args = list(
+        fill = "red",
+        color = "blue",
+        na.rm = TRUE
+      ),
+      ysidehistogram.args = list(
+        fill = "yellow",
+        color = "blue",
+        na.rm = TRUE
+      )
+    ) +
+      scale_x_continuous(breaks = seq(1, 6, 1), limits = (c(1, 6))) +
+      scale_y_continuous(breaks = seq(10, 40, 10), limits = (c(10, 40)))
+  )
+})
