@@ -10,45 +10,42 @@ if (require("afex")) {
     desc = "basic plotting works - two groups",
     code = {
       skip_on_cran()
-      skip_if(getRversion() < "3.6")
+
 
       # plot
       set.seed(123)
-      p1 <-
-        ggwithinstats(
-          data = data_bugs_2,
-          x = condition,
-          y = desire,
-          k = 4,
-          conf.level = 0.99,
-          outlier.tagging = TRUE,
-          outlier.label = "region",
-          outlier.coef = 1.5,
-          bf.message = TRUE,
-          pairwise.comparisons = TRUE,
-          ggsignif.args = list(textsize = 6, tip_length = 0.01),
-          pairwise.annotation = "asterisk",
-          point.path.args = list(color = "red"),
-          centrality.path.args = list(color = "blue", size = 2, alpha = 0.8),
-          centrality.point.args = list(size = 3, color = "darkgreen", alpha = 0.5),
-          title = "bugs dataset",
-          caption = "From `jmv` package"
-        )
+      p1 <- ggwithinstats(
+        data = data_bugs_2,
+        x = condition,
+        y = desire,
+        k = 4,
+        conf.level = 0.99,
+        outlier.tagging = TRUE,
+        outlier.label = "region",
+        outlier.coef = 1.5,
+        bf.message = TRUE,
+        pairwise.comparisons = TRUE,
+        ggsignif.args = list(textsize = 6, tip_length = 0.01),
+        point.path.args = list(color = "red"),
+        centrality.path.args = list(color = "blue", size = 2, alpha = 0.8),
+        centrality.point.args = list(size = 3, color = "darkgreen", alpha = 0.5),
+        title = "bugs dataset",
+        caption = "From `jmv` package"
+      )
 
       # build the plot
       pb1 <- ggplot2::ggplot_build(p1)
 
       # subtitle
       set.seed(123)
-      p1_subtitle <-
-        statsExpressions::two_sample_test(
-          data = data_bugs_2,
-          x = condition,
-          y = desire,
-          k = 4,
-          paired = TRUE,
-          conf.level = 0.99
-        )$expression[[1]]
+      p1_subtitle <- statsExpressions::two_sample_test(
+        data = data_bugs_2,
+        x = condition,
+        y = desire,
+        k = 4,
+        paired = TRUE,
+        conf.level = 0.99
+      )$expression[[1]]
 
       # check data
       set.seed(123)
@@ -78,45 +75,42 @@ if (require("afex")) {
     desc = "basic plotting works - more than two groups",
     code = {
       skip_on_cran()
-      skip_if(getRversion() < "3.6")
+
 
       if (utils::packageVersion("BayesFactor") >= package_version("0.9.12-4.3")) {
         library(WRS2)
 
         # plot
         set.seed(123)
-        p1 <-
-          ggwithinstats(
-            data = WineTasting,
-            x = Wine,
-            y = "Taste",
-            type = "p",
-            bf.message = TRUE,
-            k = 4,
-            conf.level = 0.99,
-            outlier.tagging = TRUE,
-            outlier.coef = 2.5,
-            pairwise.comparisons = TRUE,
-            pairwise.annotation = "asterisk",
-            title = "wine tasting data",
-            caption = "From `WRS2` package"
-          )
+        p1 <- ggwithinstats(
+          data = WineTasting,
+          x = Wine,
+          y = Taste,
+          type = "p",
+          bf.message = TRUE,
+          k = 4,
+          conf.level = 0.99,
+          outlier.tagging = TRUE,
+          outlier.coef = 2.5,
+          pairwise.comparisons = TRUE,
+          title = "wine tasting data",
+          caption = "From `WRS2` package"
+        )
 
         # build the plot
         pb1 <- ggplot2::ggplot_build(p1)
 
         # subtitle
         set.seed(123)
-        p1_subtitle <-
-          statsExpressions::oneway_anova(
-            data = WineTasting,
-            x = "Wine",
-            y = Taste,
-            type = "p",
-            k = 4,
-            paired = TRUE,
-            conf.level = 0.99
-          )$expression[[1]]
+        p1_subtitle <- statsExpressions::oneway_anova(
+          data = WineTasting,
+          x = Wine,
+          y = Taste,
+          type = "p",
+          k = 4,
+          paired = TRUE,
+          conf.level = 0.99
+        )$expression[[1]]
 
         # check data
         set.seed(123)
@@ -152,7 +146,7 @@ if (require("afex")) {
     desc = "checking subtitle outputs - without NAs",
     code = {
       skip_on_cran()
-      skip_if(getRversion() < "3.6")
+
 
       if (utils::packageVersion("BayesFactor") >= package_version("0.9.12-4.3")) {
         set.seed(123)
@@ -164,100 +158,89 @@ if (require("afex")) {
             type = "np",
             ggsignif.args = list(textsize = 6, tip_length = 0.01),
             pairwise.display = "s",
-            pairwise.annotation = "p",
             outlier.tagging = FALSE,
             conf.level = 0.90
           )
 
         set.seed(123)
-        p1_subtitle <-
-          statsExpressions::oneway_anova(
-            data = iris_long,
-            x = condition,
-            y = value,
-            type = "np",
-            paired = TRUE,
-            conf.level = 0.90
-          )$expression[[1]]
+        p1_subtitle <- statsExpressions::oneway_anova(
+          data = iris_long,
+          x = condition,
+          y = value,
+          type = "np",
+          paired = TRUE,
+          conf.level = 0.90
+        )$expression[[1]]
 
         set.seed(123)
-        p2 <-
-          suppressWarnings(ggwithinstats(
-            data = iris_long,
-            x = condition,
-            y = value,
-            type = "r",
-            pairwise.display = "ns",
-            outlier.tagging = FALSE,
-            pairwise.annotation = "p-value",
-            conf.level = 0.90
-          ))
+        p2 <- suppressWarnings(ggwithinstats(
+          data = iris_long,
+          x = condition,
+          y = value,
+          type = "r",
+          pairwise.display = "ns",
+          outlier.tagging = FALSE,
+          conf.level = 0.90
+        ))
 
         set.seed(123)
-        p2_subtitle <-
-          statsExpressions::oneway_anova(
-            data = iris_long,
-            x = condition,
-            y = value,
-            paired = TRUE,
-            type = "r",
-            conf.level = 0.90
-          )$expression[[1]]
+        p2_subtitle <- statsExpressions::oneway_anova(
+          data = iris_long,
+          x = condition,
+          y = value,
+          paired = TRUE,
+          type = "r",
+          conf.level = 0.90
+        )$expression[[1]]
 
         set.seed(123)
-        p3 <-
-          suppressWarnings(ggwithinstats(
-            data = VR_dilemma,
-            x = modality,
-            y = score,
-            type = "r",
-            k = 3,
-            nboot = 25,
-            pairwise.comparisons = TRUE,
-            pairwise.display = "all",
-            pairwise.annotation = "p",
-            bf.message = TRUE
-          ))
+        p3 <- suppressWarnings(ggwithinstats(
+          data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+          x = condition,
+          y = desire,
+          type = "r",
+          k = 3,
+          nboot = 25,
+          pairwise.comparisons = TRUE,
+          pairwise.display = "all",
+          bf.message = TRUE
+        ))
 
         set.seed(123)
-        p3_subtitle <-
-          suppressWarnings(statsExpressions::two_sample_test(
-            data = VR_dilemma,
-            x = modality,
-            y = score,
-            paired = TRUE,
-            type = "r",
-            k = 3,
-            nboot = 25
-          )$expression[[1]])
+        p3_subtitle <- suppressWarnings(statsExpressions::two_sample_test(
+          data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+          x = condition,
+          y = desire,
+          paired = TRUE,
+          type = "r",
+          k = 3,
+          nboot = 25
+        )$expression[[1]])
 
         set.seed(123)
-        p4 <-
-          ggwithinstats(
-            data = VR_dilemma,
-            x = modality,
-            y = score,
-            type = "np",
-            k = 4,
-            nboot = 15,
-            conf.level = 0.50,
-            pairwise.comparisons = TRUE,
-            pairwise.display = "all",
-            pairwise.annotation = "p"
-          )
+        p4 <- ggwithinstats(
+          data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+          x = condition,
+          y = desire,
+          type = "np",
+          k = 4,
+          nboot = 15,
+          conf.level = 0.50,
+          pairwise.comparisons = TRUE,
+          pairwise.display = "all"
+        )
 
         set.seed(123)
-        p4_subtitle <-
-          suppressWarnings(statsExpressions::two_sample_test(
-            data = VR_dilemma,
-            x = modality,
-            y = score,
-            type = "np",
-            conf.level = 0.50,
-            paired = TRUE,
-            k = 4,
-            nboot = 15
-          )$expression[[1]])
+        p4_subtitle <- suppressWarnings(statsExpressions::two_sample_test(
+          data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+          x = condition,
+          y = desire,
+          type = "np",
+          conf.level = 0.50,
+          paired = TRUE,
+          k = 4,
+          nboot = 15
+        )$expression[[1]])
 
         # built plots
         pb1 <- ggplot2::ggplot_build(p1)
@@ -278,14 +261,13 @@ if (require("afex")) {
         expect_snapshot(within(pb4$plot$labels, rm(subtitle)))
 
 
-        p5 <-
-          ggwithinstats(
-            data = iris_long,
-            x = condition,
-            y = value,
-            type = "bayes",
-            pairwise.comparisons = TRUE
-          )
+        p5 <- ggwithinstats(
+          data = iris_long,
+          x = condition,
+          y = value,
+          type = "bayes",
+          pairwise.comparisons = TRUE
+        )
 
         expect_s3_class(p5, "ggplot")
 
@@ -310,15 +292,14 @@ if (require("afex")) {
       library(WRS2)
 
       # plot
-      p <-
-        ggwithinstats(
-          data = WineTasting,
-          x = Wine,
-          y = Taste,
-          results.subtitle = FALSE,
-          pairwise.comparisons = TRUE,
-          ggplot.component = ggplot2::labs(y = "Taste rating")
-        )
+      p <- ggwithinstats(
+        data = WineTasting,
+        x = Wine,
+        y = Taste,
+        results.subtitle = FALSE,
+        pairwise.comparisons = TRUE,
+        ggplot.component = ggplot2::labs(y = "Taste rating")
+      )
 
       # build plot
       pb <- ggplot2::ggplot_build(p)
@@ -336,27 +317,25 @@ if (require("afex")) {
       set.seed(123)
       library(ggstatsplot)
 
-      p1 <-
-        ggwithinstats(
-          iris_long,
-          condition,
-          value,
-          centrality.point.args = list(size = 5, alpha = 0.5, color = "darkred"),
-          centrality.path = TRUE,
-          results.subtitle = FALSE,
-          pairwise.comparisons = FALSE
-        )
+      p1 <- ggwithinstats(
+        iris_long,
+        condition,
+        value,
+        centrality.point.args = list(size = 5, alpha = 0.5, color = "darkred"),
+        centrality.path = TRUE,
+        results.subtitle = FALSE,
+        pairwise.comparisons = FALSE
+      )
 
-      p2 <-
-        ggwithinstats(
-          iris_long,
-          condition,
-          value,
-          centrality.point.args = list(size = 5, alpha = 0.5, color = "darkred"),
-          centrality.path = FALSE,
-          results.subtitle = FALSE,
-          pairwise.comparisons = FALSE
-        )
+      p2 <- ggwithinstats(
+        iris_long,
+        condition,
+        value,
+        centrality.point.args = list(size = 5, alpha = 0.5, color = "darkred"),
+        centrality.path = FALSE,
+        results.subtitle = FALSE,
+        pairwise.comparisons = FALSE
+      )
 
       pb1 <- ggplot2::ggplot_build(p1)
       pb2 <- ggplot2::ggplot_build(p2)
