@@ -26,8 +26,8 @@ test_that(
     expect_true(inherits(
       grouped_gghistostats(
         data = ggplot2::msleep,
-        x = "brainwt",
-        grouping.var = "vore",
+        x = brainwt,
+        grouping.var = vore,
         type = "r",
         results.subtitle = FALSE,
         normal.curve = TRUE,
@@ -53,22 +53,20 @@ test_that(
     df <- dplyr::filter(ggplot2::msleep, vore == "omni")
 
     set.seed(123)
-    ls_results <-
-      grouped_gghistostats(
-        data = df,
-        x = brainwt,
-        grouping.var = vore,
-        test.value = 0.25,
-        output = "subtitle"
-      )
+    ls_results <- grouped_gghistostats(
+      data = df,
+      x = brainwt,
+      grouping.var = vore,
+      test.value = 0.25,
+      output = "subtitle"
+    )
 
     set.seed(123)
-    basic_results <-
-      statsExpressions::one_sample_test(
-        data = df,
-        x = brainwt,
-        test.value = 0.25
-      )$expression[[1]]
+    basic_results <- statsExpressions::one_sample_test(
+      data = df,
+      x = brainwt,
+      test.value = 0.25
+    )$expression[[1]]
 
     # tests
     expect_equal(ls_results$`omni`, basic_results)
