@@ -1,3 +1,5 @@
+# vdiffr output --------------------------------------------------
+
 test_that(
   desc = "grouped_ggscatterstats works",
   code = {
@@ -8,149 +10,91 @@ test_that(
       grouped_ggscatterstats(
         data = iris,
         x = Sepal.Length,
-        y = Petal.Width
+        y = Petal.Width,
       )
     )
 
     # without any labelling
     set.seed(123)
-    expect_true(inherits(
-      grouped_ggscatterstats(
+    vdiffr::expect_doppelganger(
+      title = "without any labelling",
+      fig = grouped_ggscatterstats(
         data = iris,
-        x = Sepal.Length,
-        y = Petal.Width,
-        grouping.var = Species,
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
+        Sepal.Length,
+        Petal.Width,
+        grouping.var = Species
+      )
+    )
 
     # create a smaller dataset
     set.seed(123)
-    df <- dplyr::sample_frac(tbl = movies_long, size = 0.25) %>%
+    df <- dplyr::sample_frac(movies_long, size = 0.25) %>%
       dplyr::filter(
         mpaa %in% c("R", "PG-13"),
         genre %in% c("Drama", "Comedy")
       )
 
-    # both quoted
-    set.seed(123)
-    expect_true(inherits(
-      grouped_ggscatterstats(
-        data = df,
-        x = length,
-        y = rating,
-        label.expression = "length > 150",
-        label.var = "title",
-        grouping.var = mpaa,
-        type = "bayes",
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
-
     # both unquoted
     set.seed(123)
-    expect_true(inherits(
-      grouped_ggscatterstats(
+    vdiffr::expect_doppelganger(
+      title = "both labelling args unquoted",
+      fig = grouped_ggscatterstats(
         data = df,
         x = length,
         y = rating,
         label.expression = budget > 150,
         label.var = title,
         grouping.var = mpaa,
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
-
-    # one quoted, one unquoted
-    set.seed(123)
-    expect_true(inherits(
-      grouped_ggscatterstats(
-        data = df,
-        x = length,
-        y = rating,
-        label.expression = budget > 150,
-        label.var = "title",
-        grouping.var = mpaa,
-        type = "p",
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
-
-    set.seed(123)
-    expect_true(inherits(
-      grouped_ggscatterstats(
-        data = df,
-        x = "length",
-        y = "rating",
-        grouping.var = "mpaa",
-        type = "r",
-        label.expression = "budget > 150",
-        label.var = title,
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
+        results.subtitle = FALSE
+      )
+    )
 
     # without point labelling
     set.seed(123)
-    expect_true(inherits(
-      grouped_ggscatterstats(
+    vdiffr::expect_doppelganger(
+      title = "without point labelling",
+      fig = grouped_ggscatterstats(
         data = df,
-        x = "length",
+        x = length,
         y = rating,
         grouping.var = mpaa,
         label.expression = "length > 150",
-        type = "np",
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
+        results.subtitle = FALSE
+      )
+    )
 
     # labeling all points (without expression, i.e.)
     set.seed(123)
-    expect_true(inherits(
-      grouped_ggscatterstats(
-        data = dplyr::sample_frac(tbl = df, size = 0.1),
-        x = "length",
+    vdiffr::expect_doppelganger(
+      title = "labeling all points",
+      fig = grouped_ggscatterstats(
+        data = dplyr::sample_frac(df, size = 0.1),
+        x = length,
         y = rating,
         grouping.var = mpaa,
         label.var = title,
         label.expression = NULL,
         type = "np",
-        results.subtitle = FALSE,
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
+        results.subtitle = FALSE
+      )
+    )
 
     # checking if ggplot component addition works
     set.seed(123)
-    expect_true(inherits(
-      grouped_ggscatterstats(
+    vdiffr::expect_doppelganger(
+      title = "aesthetic modification",
+      fig = grouped_ggscatterstats(
         data = ggplot2::msleep,
         x = sleep_total,
         y = bodywt,
         results.subtitle = FALSE,
-        grouping.var = "vore",
+        grouping.var = vore,
         xlab = "total sleep",
         ylab = "body weight",
         caption = "source: ggplot2 package",
-        type = "bayes",
-        ggplot.component = scale_y_continuous(breaks = seq(0, 6000, 1000)),
-        marginal = FALSE
-      ),
-      what = "gg"
-    ))
+        ggplot.component = scale_y_continuous(breaks = seq(0, 6000, 1000))
+      )
+    )
   }
 )
 
@@ -165,26 +109,24 @@ test_that(
     df <- dplyr::filter(movies_long, genre %in% c("Action Drama"))
 
     set.seed(123)
-    ls_results <-
-      grouped_ggscatterstats(
-        data = df,
-        x = rating,
-        y = "length",
-        k = 3,
-        conf.level = 0.99,
-        grouping.var = genre,
-        output = "subtitle"
-      )
+    ls_results <- grouped_ggscatterstats(
+      data = df,
+      x = rating,
+      y = length,
+      k = 3,
+      conf.level = 0.99,
+      grouping.var = genre,
+      output = "subtitle"
+    )
 
     set.seed(123)
-    basic_results <-
-      statsExpressions::corr_test(
-        data = df,
-        x = "rating",
-        y = length,
-        k = 3,
-        conf.level = 0.99
-      )$expression[[1]]
+    basic_results <- statsExpressions::corr_test(
+      data = df,
+      x = rating,
+      y = length,
+      k = 3,
+      conf.level = 0.99
+    )$expression[[1]]
 
     # tests
     expect_equal(length(ls_results), 1L)
